Developer notes and documentation
=================================

ARA static files and assets
---------------------------

This documents the files and assets ARA uses in it's web application.

Patternfly CSS, JS and Fonts
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ARA uses the Patternfly_ CSS framework.
The current version of Patternfly is `3.12.0`_.

The Patternfly assets are imported directly from
`Patternfly's compiled source`_.

.. _Patternfly: http://www.patternfly.org/#_
.. _3.12.0: https://github.com/patternfly/patternfly/releases/tag/v3.12.0
.. _Patternfly's compiled source: https://github.com/patternfly/patternfly/tree/v3.12.0/dist

jquery.matchHeight
~~~~~~~~~~~~~~~~~~

Patternfly's vertical navigation needs the `jquery.matchHeight`_ library.
The version of jquery.matchHeight is currently `0.7.0`_.

This is imported directly from the `jquery.matchHeight source`_.

.. _jquery.matchHeight: https://github.com/liabru/jquery-match-height
.. _0.7.0: https://github.com/liabru/jquery-match-height/releases/tag/0.7.0
.. _jquery.matchHeight source: https://github.com/liabru/jquery-match-height/tree/0.7.0

Bootstrap JS
~~~~~~~~~~~~

Patternfly leverages Bootstrap_ and requires bootstrap.js.
The current version of Bootstrap is `3.3.7`_.

This is imported directly from the `Bootstrap compiled source`_.

.. _Bootstrap: http://getbootstrap.com/
.. _3.3.7: https://github.com/twbs/bootstrap/releases/tag/v3.3.7
.. _Bootstrap compiled source: https://github.com/twbs/bootstrap/tree/v3.3.7/dist
